@@ -452,10 +452,11 @@ def main():
                  
             #if previous data storage file exists, delete it
             for file in file_matches: 
-                filepath = os.path.join(mypath,file)    
+                filepath = os.path.join(mypath,file)
+                if "_archived_" in file:
+                    os.remove(filepath)
                 if os.path.exists(filepath):
                     os.rename(filepath, os.path.join(mypath, "_archived_" + file))
-                    #os.remove(filepath)
                 else:
                     print(f"Cannot delete the file ({filepath}) because it does not exist")   
                     
@@ -562,12 +563,14 @@ def main():
                  
             #if previous data storage file exists, delete it
             for file in file_matches: 
-                filepath = os.path.join(mypath,file)    
+                filepath = os.path.join(mypath,file)
+                if "_archived_" in file:
+                    os.remove(filepath)
                 if os.path.exists(filepath):
                     os.rename(filepath, os.path.join(mypath, "_archived_" + file))
-                    #os.remove(filepath)
                 else:
-                  print(f"Cannot delete the file ({filepath}) because it does not exist")   
+                  print(f"Cannot delete the file ({filepath}) because it does not exist")
+                  
         elif start_fresh.lower() == 'n':
             ci = ds.Cal_End(True)
             ci.run_cal()
